pub struct AesHmacSha2EncryptedData {
pub iv: [u8; 16],
pub ciphertext: Base64,
pub mac: [u8; 32],
}Expand description
Encrypted data for the AES-CTR/HMAC-SHA-256 secret storage algorithm.
Fields
iv: [u8; 16]The initialization vector that was used to encrypt the ciphertext.
ciphertext: Base64The ciphertext of the message.
mac: [u8; 32]The message authentication code ensuring that the message was not forged.